gocatdoc

package module
v0.0.41 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 3, 2025 License: MIT Imports: 15 Imported by: 0

README

Go-catdoc, get text and metadata from .doc files.

GoDoc Tests

Uses Wazero to run catdoc as webassembly in Go. The catdoc source is slightly modified to support reading metadata in .doc.
The msdoc.hexpat file is a pattern file for imhex that can parse the summaryinformation ole object inside the .doc file.

To compile the webassembly binary, go to ./catdoc/src/ and run make catdoc-wasm.
To run the tests, do go test ./...

Usage:

f, err := os.Open("test.doc")
text, err := gocatdoc.GetTextFromFile(f)

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetAnnotationAuthorsFromFile

func GetAnnotationAuthorsFromFile(file io.ReadSeeker) ([]string, error)

func GetCommentsFromFile

func GetCommentsFromFile(file io.ReadSeeker) (string, error)

func GetKeywordsFromFile

func GetKeywordsFromFile(file io.ReadSeeker) (string, error)

func GetSubjectFromFile

func GetSubjectFromFile(file io.ReadSeeker) (string, error)

func GetTextFromFile

func GetTextFromFile(file io.ReadSeeker) (string, error)

GetTextFromFile returns the plain text from a Word document.

func GetTitleFromFile

func GetTitleFromFile(file io.ReadSeeker) (string, error)

func GetVersion

func GetVersion() (string, error)

Types

This section is empty.

Jump to